@@ -13,25 +13,36 @@ __maintainer__ = "Tomas Poveda"
 __email__ = "tpovedatd@gmail.com"
 
 import os
-import inspect
 import logging.config
 
-import tpDcc as tp
-from tpDcc.libs.python import python
+import tpDcc.loader
+
+import artellapipe.register
+from artellapipe.core import asset, node, shot, sequence
+from artellapipe.managers import assets, files, names, shaders, shots, sequences, menus, shelf, tools, libs, tracking
+from artellapipe.managers import dependencies, playblasts, ocio
+from artellapipe.widgets import dialog, window, syncdialog
+
+# =================================================================================
+
+PACKAGE = 'artellapipe'
+
+# =================================================================================
 
 
-def init(do_reload=False, import_libs=True, dev=False):
+def init(dev=False):
     """
     Initializes module
-    :param do_reload: bool, Whether to reload modules or not
+    :param import_libs: bool, Whether to import deps libraries by default or not
     :param dev: bool, Whether artellapipe is initialized in dev mode or not
     """
 
-    from tpDcc.libs.python import importer
-    from artellapipe import register
+    if dev:
+        artellapipe.register.cleanup()
+        register_classes()
 
     logger = create_logger()
-    register.register_class('logger', logger)
+    artellapipe.register.register_class('logger', logger)
 
     if not dev:
         import sentry_sdk
@@ -40,51 +51,10 @@ def init(do_reload=False, import_libs=True, dev=False):
         except (RuntimeError, ImportError):
             sentry_sdk.init("https://eb70c73942e049e4a08f5a01ba788c4b@sentry.io/1771171", default_integrations=False)
 
-    class ArtellaPipe(importer.Importer, object):
-        def __init__(self, debug=False):
-            super(ArtellaPipe, self).__init__(module_name='artellapipe', debug=debug)
-
-        def get_module_path(self):
-            """
-            Returns path where tpNameIt module is stored
-            :return: str
-            """
-
-            try:
-                mod_dir = os.path.dirname(
-                    inspect.getframeinfo(inspect.currentframe()).filename)
-            except Exception:
-                try:
-                    mod_dir = os.path.dirname(__file__)
-                except Exception:
-                    try:
-                        import artellapipe
-                        mod_dir = artellapipe.__path__[0]
-                    except Exception:
-                        return None
-
-            return mod_dir
-
-    packages_order = [
-        'artellapipe.utils',
-        'artellapipe.core',
-        'artellapipe.widgets'
-    ]
-
-    if import_libs:
-        import tpDcc.loader
-        tpDcc.loader.init(do_reload=do_reload, dev=dev)
-        # import tpNameIt
-        # tpNameIt.init(do_reload=do_reload)
-
-    artella_importer = importer.init_importer(importer_class=ArtellaPipe, do_reload=False, debug=dev)
-    artella_importer.import_packages(
-        order=packages_order,
-        only_packages=False)
-    if do_reload:
-        artella_importer.reload_all()
-
-    init_dcc(do_reload=do_reload)
+    # Get DCC
+    dcc_mod = tpDcc.loader.get_dcc_loader_module(package='artellapipe.dccs')
+    if dcc_mod:
+        dcc_mod.init(dev=dev)
 
     # When working in production, we use custom exception hook to show message box to user
     if not dev:
@@ -92,20 +62,6 @@ def init(do_reload=False, import_libs=True, dev=False):
         exceptions.ArtellaExceptionHook()
 
 
-def init_dcc(do_reload=False):
-    """
-    Checks DCC we are working on an initializes proper variables
-    :param do_reload: bool
-    """
-
-    if tp.is_maya():
-        from artellapipe.dccs import maya as maya_dcc
-        maya_dcc.init(do_reload=do_reload)
-    elif tp.is_houdini():
-        from artellapipe.dccs import houdini as houdini_dcc
-        houdini_dcc.init(do_reload=do_reload)
-
-
 def create_logger():
     """
     Returns logger of current module
@@ -138,19 +94,7 @@ def get_logging_config():
     return os.path.normpath(os.path.join(os.path.dirname(__file__), '__logging__.ini'))
 
 
-def get_logging_level():
-    """
-    Returns logging level to use
-    :return: str
-    """
-
-    if os.environ.get('ARTELLAPIPE_LOG_LEVEL', None):
-        return os.environ.get('ARTELLAPIPE_LOG_LEVEL')
-
-    return os.environ.get('ARTELLAPIPE_LOG_LEVEL', 'WARNING')
-
-
-def set_project(project_class, do_reload=False):
+def set_project(project_class):
     """
     This functions sets the given class instance as the current Artella project used
     :param project_class: ArtellaProject
@@ -168,8 +112,8 @@ def set_project(project_class, do_reload=False):
     artellapipe.__dict__[project_class.__name__.lower()] = project_inst
 
     register_resources(project_inst)
-    register_libs(project_inst, do_reload=do_reload)
-    register_tools(project_inst, dev=project_inst.get_environment().lower() == 'development', do_reload=do_reload)
+    register_libs(project_inst)
+    register_tools(project_inst, dev=project_inst.get_environment().lower() == 'development')
     project_inst.init()
 
 
@@ -178,6 +122,7 @@ def register_configs():
     Registers aretellapipe configuration files
     """
 
+    import tpDcc as tp
     from artellapipe import config
 
     artella_configs_path = os.environ.get('ARTELLA_CONFIGS_PATH', None)
@@ -192,6 +137,8 @@ def register_resources(project):
     Registers artellapipe and project resources
     """
 
+    import tpDcc as tp
+
     project_resources_paths = project.get_resources_paths()
     for resources_key, resources_path in project_resources_paths.items():
         if not os.path.isdir(resources_path):
@@ -205,24 +152,23 @@ def register_resources(project):
     tp.ResourcesMgr().register_resource(resources_path)
 
 
-def register_libs(project_inst, do_reload=False):
+def register_libs(project_inst):
     """
     Function that registera all available libs for given project
     :param project_inst: ArtellaProject
-    :param do_reload: bool
     """
 
-    import artellapipe
+    from tpDcc.libs.python import python
 
     if python.is_python2():
         import pkgutil as loader
     else:
         import importlib as loader
 
-    libs = project_inst.config_data.get('libs', list())
+    libs_found = project_inst.config_data.get('libs', list())
     libs_to_register = dict()
     libs_path = '{}.libs.{}'
-    for lib_name in libs:
+    for lib_name in libs_found:
         for pkg in ['artellapipe', project_inst.get_clean_name()]:
             pkg_path = libs_path.format(pkg, lib_name)
             try:
@@ -236,30 +182,36 @@ def register_libs(project_inst, do_reload=False):
 
     for pkg_loaders in libs_to_register.values():
         for pkg_loader in pkg_loaders:
-            artellapipe.LibsMgr().register_lib(project=project_inst, pkg_loader=pkg_loader, do_reload=do_reload)
+            libs.LibsManager().register_lib(project=project_inst, pkg_loader=pkg_loader)
 
 
-def register_tools(project_inst, dev=False, do_reload=False):
+def register_tools(project_inst, dev=False):
     """
     Function that register all available tools for given project
     :param project_inst: ArtellaProject
+    :param dev: bool
     """
 
+    import tpDcc as tp
     import artellapipe.toolsets
 
     package_names = ['artellapipe', project_inst.get_clean_name()]
 
     # Tools
     project_name = project_inst.get_clean_name()
-    tools_to_load = project_inst.config_data.get('tools', list())
+    tools_to_register = project_inst.config_data.get('tools', list())
     config_dict = {'project': project_name}
-    tp.ToolsMgr().load_package_tools(
-        package_name='artellapipe', root_package_name=project_name, tools_to_load=tools_to_load,
+    tp.ToolsMgr().register_package_tools(
+        pkg_name=PACKAGE, root_pkg_name=project_name, tools_to_register=tools_to_register,
         config_dict=config_dict, dev=dev)
-    tp.ToolsMgr().load_package_tools(
-        package_name=project_name, tools_to_load=tools_to_load, config_dict=config_dict, dev=dev)
+    tp.ToolsMgr().register_package_tools(
+        pkg_name=project_name, tools_to_register=tools_to_register, config_dict=config_dict, dev=dev)
+
+    tp.ToolsMgr().load_registered_tools(project_name)
+    tp.ToolsMgr().load_registered_tools(PACKAGE)
 
     artellapipe.MenusMgr().create_menus(project_inst.get_clean_name(), project=project_inst)
+    shelf.ArtellaShelfManager().create_shelf(project=project_inst)
 
     # Toolsets
     # NOTE: Project specific toolsets paths MUST be registered in project specific loader
@@ -269,5 +221,31 @@ def register_tools(project_inst, dev=False, do_reload=False):
     for project_toolset_path in project_inst.get_toolsets_paths():
         tp.ToolsetsMgr().register_path(project_inst.get_clean_name(), project_toolset_path)
     for package_name in package_names:
-        tp.ToolsetsMgr().load_registered_toolsets(
-            package_name, tools_to_load=tools_to_load, dev=dev, do_reload=do_reload)
+        tp.ToolsetsMgr().load_registered_toolsets(package_name, tools_to_load=tools_to_register)
+
+
+def register_classes():
+    artellapipe.register.register_class('Asset', asset.ArtellaAsset)
+    artellapipe.register.register_class('AssetNode', node.ArtellaAssetNode)
+    artellapipe.register.register_class('Shot', shot.ArtellaShot)
+    artellapipe.register.register_class('Sequence', sequence.ArtellaSequence)
+    artellapipe.register.register_class('Window', window.ArtellaWindow)
+    artellapipe.register.register_class('Dialog', dialog.ArtellaDialog)
+    artellapipe.register.register_class('SyncFileDialog', syncdialog.ArtellaSyncFileDialog)
+    artellapipe.register.register_class('SyncPathDialog', syncdialog.ArtellaSyncPathDialog)
+    artellapipe.register.register_class('AssetsMgr', assets.AssetsManager)
+    artellapipe.register.register_class('FilesMgr', files.FilesManager)
+    artellapipe.register.register_class('NamesMgr', names.NamesManager)
+    artellapipe.register.register_class('ShadersMgr', shaders.ShadersManager)
+    artellapipe.register.register_class('ShotsMgr', shots.ShotsManager)
+    artellapipe.register.register_class('SequencesMgr', sequences.SequencesManager)
+    artellapipe.register.register_class('MenusMgr', menus.MenusManager)
+    artellapipe.register.register_class('LibsMgr', libs.LibsManager)
+    artellapipe.register.register_class('ToolsMgr', tools.ToolsManager)
+    artellapipe.register.register_class('DepsMgr', dependencies.DependenciesManager)
+    artellapipe.register.register_class('Tracker', tracking.TrackingManager)
+    artellapipe.register.register_class('OCIOMgr', ocio.OCIOManager)
+    artellapipe.register.register_class('PlayblastsMgr', playblasts.ArtellaPlayblastsSingleton)
+
+
+register_classes()
