@@ -13,15 +13,11 @@ __maintainer__ = "Tomas Poveda"
 __email__ = "tpovedatd@gmail.com"
 
 import tpDcc
-from tpDcc.libs.python import decorators
 
 import artellapipe
-import artellapipe.register
 
 
-class ArtellaToolsManager(object):
-    def __init__(self):
-        super(ArtellaToolsManager, self).__init__()
+class ToolsManager(object):
 
     def run_tool(self, tool_id, do_reload=False, debug=False, project=None, *args, **kwargs):
         """
@@ -37,12 +33,3 @@ class ArtellaToolsManager(object):
 
         return tpDcc.ToolsMgr().launch_tool_by_id(
             tool_id, do_reload=do_reload, debug=debug, project=project, *args, **kwargs)
-
-
-@decorators.Singleton
-class ArtellaToolsManagerSingleton(ArtellaToolsManager, object):
-    def __init__(self):
-        ArtellaToolsManager.__init__(self)
-
-
-artellapipe.register.register_class('ToolsMgr', ArtellaToolsManagerSingleton)
